#
# spec file for package php-gnupg
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_name    gnupg

%define flavor php8%{nil}
%if "%{flavor}" == "" || (0%{?suse_version} >= 1550 && "%{flavor}" == "php7")
%define php_name php
ExclusiveArch:  do-not-build
%else
%define php_name %{flavor}
%endif
%if 0%{?suse_version} <= 1500
%define php_extdir  %(%{__php_config} --extension-dir)
%define php_cfgdir  %{_sysconfdir}/%{php_name}/conf.d
%endif

Name:           %{php_name}-%{pkg_name}
Version:        1.5.2
Release:        1.1
Summary:        PHP wrapper around the gpgme library
License:        BSD-2-Clause
Group:          Productivity/Networking/Web/Servers
URL:            https://pecl.php.net/gnupg
Source0:        https://pecl.php.net/get/%{pkg_name}-%{version}.tgz
Source1:        php-%{pkg_name}-rpmlintrc
Source2:        no_uid_hint_msg.gpg
BuildRequires:  %{php_name}-devel
BuildRequires:  gpgme-devel
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}
Provides:       php-gnupg = %{version}
Obsoletes:      php-gnupg < %{version}

%description
This extension provides methods to interact with gnupg.

%prep
%setup -q -n %{pkg_name}-%{version}
cp %{SOURCE2} tests/

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%{__phpize}
%configure --disable-rpath --with-gnupg=%{_usr} --with-libdir=%{_lib}
%make_build

%check
%make_build PHP_EXECUTABLE=%{__php} NO_INTERACTION=1 test

%install
%make_install INSTALL_ROOT=%{buildroot}
mkdir -p %{buildroot}%{php_cfgdir}
cat >> %{buildroot}%{php_cfgdir}/%{pkg_name}.ini << EOF
; comment out next line to disable %{pkg_name} extension in php
extension=%{pkg_name}.so"
EOF

%files
%license LICENSE
%doc README.md
%config(noreplace) %{php_cfgdir}/%{pkg_name}.ini
%{php_extdir}/%{pkg_name}.so

%changelog
* Sun Apr 27 2025 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.5.2
  * Fixed GH-37: gnupg_decrypt() returns false when decrypting an
    encrypted empty string
  * Fixed GH-46: gnupg_decrypt() segfaults when password callback user
    ID hint is not supplied
  * Fixed 1.5.0 regressition - the deletekey `allow_secret` made
    optional again
- Add no_uid_hint_msg.gpg that was accidentally not packaged in the
  archive available from upstream
* Sat Dec 10 2022 Arjen de Korte <suse+build@de-korte.org>
- Remove php7 build for Tumbleweed (PHP 7.4 has reached EOL)
* Sat Jan  1 2022 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.5.1
  * Fixed compilation with PHP 8.1
  * Fixed build with gpgme 1.4
* Sat Apr 10 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.5.0
  * Added new README.md
* Sun Mar  7 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.5.0RC2
  * Fixed build with libgpgme 1.3
  * Fixed largefile support on 32-bit platforms
    (delete 0001_add_largefile_support.patch)
  * Fixed tests in PECL archive
    (delete gnupgt.inc and vars.inc)
* Sun Feb 21 2021 Arjen de Korte <suse+build@de-korte.org>
- Fix build on i586 (expects largefile support to be enabled)
* Sun Feb 21 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 1.5.0RC1
  * Added support for PHP 8
  * Added support for GnuPG 2.1+
  * Added argument info for all functions and methods (reflection support)
  * Added new function `gnupg_getengineinfo`
  * Added new function `gnupg_geterrorinfo`
  * Added init array argument for setting home dir and gpg binary file name
  * Added additional fields to `gnupg_keyinfo` returned array
  * Added parameter to `gnupg_keyinfo` to use `secret_only`
  * Fixed `gnupg_deletekey` to use boolean for `allow_secret` parameter
- Update to 1.4.0
  * No changes since 1.4.0RC2
- Update to 1.4.0RC2
  * Fixed ZTS issue with invalid context for a password callback
- Update to 1.4.0RC1
  * Added support for PHP 7
  * Fixed various compilation issues
- Use _multibuild to build for php7 and php8
- Use php_cfgdir and php_extdir macros to determine location of files
- Run unit tests
- Add files missing from the PECL tarball
  + gnupgt.inc
  + vars.inc
* Fri Jan 29 2016 pgajdos@suse.com
- provides php-gnupg symbol
* Tue Jan 12 2016 pgajdos@suse.com
- updated to 1.3.6
* Mon Aug 17 2009 crrodriguez@novell.com
- use versioning macros
* Fri May  4 2007 judas_iscariote@shorewall.net
- update to version 1.3.1 fixing a double-free with recent gpgme-lib
